==> libtorrent-0.7.0.tar.gz: libtorrent-0.7.0/src/data/hash_queue_node.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "hash_queue_node.h"

namespace torrent {

bool
HashQueueNode::perform(bool force) {
  if (!m_chunk->perform(m_chunk->remaining(), force))
    return false;

  m_slotDone(m_chunk->get_chunk(), m_chunk->get_hash());

  return true;
}

uint32_t
HashQueueNode::call_willneed() {
  if (!m_willneed) {
    m_willneed = true;
    m_chunk->advise_willneed(m_chunk->remaining());
  }

  return m_chunk->remaining();
}

}

==> libtorrent-0.8.3.tar.gz: libtorrent-0.8.3/src/data/hash_queue_node.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2006, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "hash_chunk.h"
#include "hash_queue_node.h"
#include "chunk_list_node.h"

namespace torrent {

uint32_t
HashQueueNode::get_index() const {
  return m_chunk->get_chunk()->index();
}

void
HashQueueNode::clear() {
  delete m_chunk;
  m_chunk = NULL;
}

uint32_t
HashQueueNode::call_willneed() {
  if (!m_willneed) {
    m_willneed = true;
    m_chunk->advise_willneed(m_chunk->remaining());
  }

  return m_chunk->remaining();
}

}
